..
    Copyright (C) 2024 CERN.

    Invenio-Preservation-Sync is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

===========================
 Invenio-Preservation-Sync
===========================

.. image:: https://github.com/inveniosoftware/invenio-preservation-sync/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-preservation-sync/actions?query=workflow%3ACI

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio-preservation-sync.svg
        :target: https://github.com/inveniosoftware/invenio-preservation-sync/releases

.. image:: https://img.shields.io/pypi/dm/invenio-preservation-sync.svg
        :target: https://pypi.python.org/pypi/invenio-preservation-sync

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-preservation-sync.svg
        :target: https://github.com/inveniosoftware/invenio-preservation-sync/blob/master/LICENSE

Invenio module that adds preservation sync integration to the platform.

Further documentation is available on
https://invenio-preservation-sync.readthedocs.io/
